@@ -16,6 +16,13 @@
 #' }
 GNRS <- function(political_division_dataframe, batches = NULL){
   
+  # Check for internet access
+  if (!is.character(getURL("www.google.com"))) {
+    message("This function requires internet access, please check your connection.")
+    return(invisible(NULL))
+  }
+  
+  
 
   # api url
   url = "http://vegbiendev.nceas.ucsb.edu:8875/gnrs_api.php" # production
@@ -72,8 +79,15 @@ GNRS <- function(political_division_dataframe, batches = NULL){
   # Construct the request
   headers <- list('Accept' = 'application/json', 'Content-Type' = 'application/json', 'charset' = 'UTF-8')
   
-  # Send the API request
-  results_json <- postForm(url, .opts=list(postfields= input_json, httpheader=headers))
+  # Send the request in a "graceful failure" wrapper for CRAN compliance
+  tryCatch(expr = results_json <-  postForm(url, .opts=list(postfields= input_json, httpheader=headers)),
+           error = function(e) {
+             message("There appears to be a problem reaching the API.") 
+             return(NULL)
+           })
+  
+  #Return NULL if API isn't working
+  if(is.null(results_json)){return(invisible(NULL))}
   
   # Convert JSON results to a data frame
   results <-  fromJSON(results_json)
