@@ -11,6 +11,12 @@
 #' 
 GNRS_version <- function(){
   
+  # Check for internet access
+  if (!is.character(getURL("www.google.com"))) {
+    message("This function requires internet access, please check your connection.")
+    return(invisible(NULL))
+  }
+
   # api url
   url = "http://vegbiendev.nceas.ucsb.edu:8875/gnrs_api.php" # production
   #url = "http://vegbiendev.nceas.ucsb.edu:9875/gnrs_api.php" # development
@@ -36,8 +42,15 @@ GNRS_version <- function(){
   # Construct the request
   headers <- list('Accept' = 'application/json', 'Content-Type' = 'application/json', 'charset' = 'UTF-8')
   
-  # Send the request again
-  results_json <- postForm(url, .opts=list(postfields= input_json, httpheader=headers))
+  # Send the request in a "graceful failure" wrapper for CRAN compliance
+  tryCatch(expr =results_json <-  postForm(url, .opts=list(postfields= input_json, httpheader=headers)),
+           error = function(e) {
+             message("There appears to be a problem reaching the API.") 
+             return(NULL)
+           })
+  
+  #Return NULL if API isn't working
+  if(is.null(results_json)){return(invisible(NULL))}
   
   # Format the results
   results <- fromJSON(results_json)
